==> jei-1.19.4-fabric-13.1.0.8-sources.jar: mezz/jei/fabric/platform/RecipeHelper.java <==
package mezz.jei.fabric.platform;

import mezz.jei.api.recipe.vanilla.IJeiBrewingRecipe;
import mezz.jei.api.recipe.vanilla.IVanillaRecipeFactory;
import mezz.jei.api.runtime.IIngredientManager;
import mezz.jei.common.platform.IPlatformRecipeHelper;
import net.minecraft.class_1856;
import net.minecraft.class_1860;
import net.minecraft.class_1869;
import net.minecraft.class_2960;
import net.minecraft.class_3955;
import net.minecraft.class_8059;
import net.minecraft.class_8060;
import net.minecraft.class_8062;
import java.util.List;
import java.util.Optional;

public class RecipeHelper implements IPlatformRecipeHelper {
    @Override
    public <T extends class_3955> int getWidth(T recipe) {
        if (recipe instanceof class_1869 shapedRecipe) {
            return shapedRecipe.method_8150();
        }
        return 0;
    }

    @Override
    public <T extends class_3955> int getHeight(T recipe) {
        if (recipe instanceof class_1869 shapedRecipe) {
            return shapedRecipe.method_8158();
        }
        return 0;
    }

    @SuppressWarnings("removal")
    @Override
    public class_1856 getBase(class_8059 recipe) {
        if (recipe instanceof net.minecraft.class_5357 legacyRecipe) {
            return legacyRecipe.field_25389;
        }
        if (recipe instanceof class_8060 transformRecipe) {
            return transformRecipe.field_42031;
        }
        if (recipe instanceof class_8062 trimRecipe) {
            return trimRecipe.field_42036;
        }
        return class_1856.field_9017;
    }

    @SuppressWarnings("removal")
    @Override
    public class_1856 getAddition(class_8059 recipe) {
        if (recipe instanceof net.minecraft.class_5357 legacyRecipe) {
            return legacyRecipe.field_25390;
        }
        if (recipe instanceof class_8060 transformRecipe) {
            return transformRecipe.field_42032;
        }
        if (recipe instanceof class_8062 trimRecipe) {
            return trimRecipe.field_42037;
        }
        return class_1856.field_9017;
    }

    @SuppressWarnings("removal")
    @Override
    public boolean isHandled(class_8059 recipe) {
        if (recipe.method_31584()) {
            return false;
        }
        return recipe instanceof net.minecraft.class_5357 ||
            recipe instanceof class_8060 ||
            recipe instanceof class_8062;
    }

    @SuppressWarnings("DataFlowIssue")
    @Override
    public Optional<class_2960> getRegistryNameForRecipe(class_1860<?> recipe) {
        class_2960 id = recipe.method_8114();
        return Optional.ofNullable(id);
    }

    @Override
    public List<IJeiBrewingRecipe> getBrewingRecipes(IIngredientManager ingredientManager, IVanillaRecipeFactory vanillaRecipeFactory) {
        return BrewingRecipeMaker.getBrewingRecipes(ingredientManager, vanillaRecipeFactory);
    }
}

==> jei-1.20-fabric-14.0.0.10-sources.jar: mezz/jei/fabric/platform/RecipeHelper.java <==
package mezz.jei.fabric.platform;

import mezz.jei.api.recipe.vanilla.IJeiBrewingRecipe;
import mezz.jei.api.recipe.vanilla.IVanillaRecipeFactory;
import mezz.jei.api.runtime.IIngredientManager;
import mezz.jei.common.platform.IPlatformRecipeHelper;
import net.minecraft.class_1856;
import net.minecraft.class_1860;
import net.minecraft.class_1869;
import net.minecraft.class_2960;
import net.minecraft.class_3955;
import net.minecraft.class_8059;
import net.minecraft.class_8060;
import net.minecraft.class_8062;
import java.util.List;
import java.util.Optional;

public class RecipeHelper implements IPlatformRecipeHelper {
    @Override
    public <T extends class_3955> int getWidth(T recipe) {
        if (recipe instanceof class_1869 shapedRecipe) {
            return shapedRecipe.method_8150();
        }
        return 0;
    }

    @Override
    public <T extends class_3955> int getHeight(T recipe) {
        if (recipe instanceof class_1869 shapedRecipe) {
            return shapedRecipe.method_8158();
        }
        return 0;
    }

    @Override
    public class_1856 getBase(class_8059 recipe) {
        if (recipe instanceof class_8060 transformRecipe) {
            return transformRecipe.field_42031;
        }
        if (recipe instanceof class_8062 trimRecipe) {
            return trimRecipe.field_42036;
        }
        return class_1856.field_9017;
    }

    @Override
    public class_1856 getAddition(class_8059 recipe) {
        if (recipe instanceof class_8060 transformRecipe) {
            return transformRecipe.field_42032;
        }
        if (recipe instanceof class_8062 trimRecipe) {
            return trimRecipe.field_42037;
        }
        return class_1856.field_9017;
    }

    @Override
    public class_1856 getTemplate(class_8059 recipe) {
        if (recipe instanceof class_8060 transformRecipe) {
            return transformRecipe.field_42030;
        }
        if (recipe instanceof class_8062 trimRecipe) {
            return trimRecipe.field_42035;
        }
        return class_1856.field_9017;
    }

    @Override
    public boolean isHandled(class_8059 recipe) {
        if (recipe.method_31584()) {
            return false;
        }
        return recipe instanceof class_8060 || recipe instanceof class_8062;
    }

    @SuppressWarnings("DataFlowIssue")
    @Override
    public Optional<class_2960> getRegistryNameForRecipe(class_1860<?> recipe) {
        class_2960 id = recipe.method_8114();
        return Optional.ofNullable(id);
    }

    @Override
    public List<IJeiBrewingRecipe> getBrewingRecipes(IIngredientManager ingredientManager, IVanillaRecipeFactory vanillaRecipeFactory) {
        return BrewingRecipeMaker.getBrewingRecipes(ingredientManager, vanillaRecipeFactory);
    }
}
